#
# spec file for package python-pyviz-comms
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#



Name:           python-pyviz-comms
Version:        3.0.2
Release:        1.1
Summary:        Tool to launch jobs, organize the output, and dissect the results
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/pyviz/pyviz_comms
Source0:        https://files.pythonhosted.org/packages/py3/p/pyviz-comms/pyviz_comms-%{version}-py3-none-any.whl
Source99:       python-pyviz-comms-rpmlintrc
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 40.8.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
Requires:       python-param
Recommends:     jupyter-jupyterlab-pyviz = %{version}
Provides:       python-pyviz_comms = %{version}-%{release}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module param}
# /SECTION
%python_subpackages

%description
PyViz-Comms offers a simple bidirectional communication architecture
for PyViz tools including support for Jupyter comms in both the
classic notebook and Jupyterlab.

%package     -n jupyter-jupyterlab-pyviz
Release:        1.1
Summary:        PyViz JupyterLab Extension
Group:          Development/Languages/Python
Requires:       jupyter-jupyterlab
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(pyviz-comms) = %{version}
Suggests:       python3-pyviz-comms

%description -n jupyter-jupyterlab-pyviz
Jupyter extension to display matplotlib plots in a widget.

This package provides the JupyterLab extension.

%prep
%setup -q -c -T

%build
# not needed

%install
%pyproject_install %{SOURCE0}
%python_expand %fdupes %{buildroot}%{$python_sitelib}
cp %{buildroot}%{python_sitelib}/pyviz_comms-%{version}.dist-info/licenses/LICENSE .
cp %{buildroot}%{python_sitelib}/pyviz_comms-%{version}.dist-info/licenses/LICENSE.txt .

%check
%pytest %{buildroot}%{python_sitelib}/pyviz_comms

%files %{python_files}
%license LICENSE LICENSE.txt
%{python_sitelib}/pyviz_comms
%{python_sitelib}/pyviz_comms-%{version}.dist-info

%files -n jupyter-jupyterlab-pyviz
%license LICENSE LICENSE.txt
%dir %{_jupyter_labextensions_dir3}/@pyviz/
%{_jupyter_labextensions_dir3}/@pyviz/jupyterlab_pyviz

%changelog
* Sun Apr 21 2024 Todd R <toddrme2178@gmail.com>
- Update to 3.0.2
  * Ensure save handler gracefully handles undefined layout data
- Update to 3.0.1
  * Add save handler for Panel Layout Builder
  * Publish again to the `pyviz` channel
- Update to 3.0.0
  * Update to JupyterLab 4
  * pip downstream dependency to fix build error
- Switch to wheel to make sure jupyterlab plugin is properly installed
- Package jupyterlab plugin
* Sat Jan 14 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.2.1
  * no release notes: adds tests, bumps js versions
- Version 2.2.0
  * Bump url-parse from 1.5.1 to 1.5.10 by @dependabot in #86
  * Track execution counts of extensions by @philippjfr in #87
  * Bump node-fetch from 2.6.1 to 2.6.7 by @dependabot in #92
  * Bump jquery-ui from 1.12.1 to 1.13.1 by @dependabot in #91
  * Bump nanoid from 3.1.23 to 3.3.1 by @dependabot in #90
  * Bump ansi-regex from 4.1.0 to 4.1.1 by @dependabot in #89
  * Bump minimist from 1.2.5 to 1.2.6 by @dependabot in #88
  * Install the tests options in the build workflow by @maximlt in
    [#95]
- Version 2.1.0
  * Bump glob-parent from 5.1.1 to 5.1.2 by @dependabot in #82
  * Implement JupyterLab Panel Preview by @philippjfr in #79
- Version 2.0.2
  * Bump ssri from 8.0.0 to 8.0.1 by @dependabot in #74
  * Bump underscore from 1.12.0 to 1.13.1 by @dependabot in #75
  * Bump lodash from 4.17.20 to 4.17.21 by @dependabot in #76
  * Bump hosted-git-info from 2.8.8 to 2.8.9 by @dependabot in #77
  * Bump normalize-url from 4.5.0 to 4.5.1 by @dependabot in #81
  * Bump browserslist from 4.16.0 to 4.16.6 by @dependabot in #78
  * Bump ws from 7.4.1 to 7.4.6 by @dependabot in #80
- Version 2.0.0
  * Bump lodash from 4.17.15 to 4.17.19 by @dependabot in #65
  * Fix build by @philippjfr in #69
  * Bump ini from 1.3.5 to 1.3.8 by @dependabot in #70
  * Bundle labextension for JupyterLab>=3.0 support by @philippjfr
    in #72
* Tue Jul 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.7.6
  * Fix compatibility with older browsers
  * Add support for comms in Google Colab
  * Add on_open callbacks to comms
* Sat Jun  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.7.4:
  * Changes not documented upstream.
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.7.3
  * Add ability to register on_error and on_stdout handlers on Comms.
* Mon Apr 22 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.7.2
  * Custom MIME type rendering now executes script tags in HTML
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.7.0
  * Send ACK and error messages as metadata
  * Small fix to handling notebook output
  * Add warning about installing extension in JupyterLab
  * Add a pyviz_extension baseclass for other projects
  * Guard against PyViz not being defined
  * Updated JLab and classic notebook extensions
* Thu Oct 11 2018 Todd R <toddrme2178@gmail.com>
- noun phrase (summary) and full sentences (description)
* Tue Oct  9 2018 Todd R <toddrme2178@gmail.com>
- Initial version
